@@ -19,8 +19,8 @@ class SQSQueuePolicy(Resource):
 
 
 class SQSQueuePolicies:
-    @classmethod
-    def sns_topic_send_message_role_policy(cls, topic_arn, queue_arn):
+    @staticmethod
+    def sns_topic_send_message_role_policy(topic_arn, queue_arn):
         document = {
             "Version": "2012-10-17",
             "Statement": [
@@ -34,3 +34,19 @@ class SQSQueuePolicies:
             ],
         }
         return document
+
+    @staticmethod
+    def eventbridge_dlq_send_message_resource_based_policy(rule_arn, queue_arn):
+        document = {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Action": "sqs:SendMessage",
+                    "Effect": "Allow",
+                    "Principal": {"Service": "events.amazonaws.com"},
+                    "Resource": queue_arn,
+                    "Condition": {"ArnEquals": {"aws:SourceArn": rule_arn}},
+                }
+            ],
+        }
+        return document
