@@ -63,6 +63,12 @@ class ImplicitRestApiPlugin(ImplicitApiPlugin):
             if not event_properties:
                 continue
 
+            if not isinstance(event_properties, dict):
+                raise InvalidEventException(
+                    logicalId,
+                    "Event 'Properties' must be an Object. If you're using YAML, this may be an indentation issue.",
+                )
+
             self._add_implicit_api_id_if_necessary(event_properties)
 
             api_id = self._get_api_id(event_properties)
